otcextensions.sdk.dcs.v1.group_message
======================================

.. automodule:: otcextensions.sdk.dms.v1.group_message

The DMS GroupMessage Class
--------------------------

The ``GroupMessage`` class inherits from
:class:`~otcextensions.sdk.sdk_resource.Resource`.

.. autoclass:: otcextensions.sdk.dms.v1.group_message.GroupMessage
   :members:
